summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp
diff options
context:
space:
mode:
authorgokhale <gokhale@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-06-12 19:11:48 +0000
committergokhale <gokhale@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-06-12 19:11:48 +0000
commitbd71727dc45649eee395d64561b8ce75f958683f (patch)
treebc828aa13818eb1ae7c422e62581ec1a860c694f /TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp
parentb47116e1d646d870860fc44fc9127fef7b550f75 (diff)
downloadATCD-bd71727dc45649eee395d64561b8ce75f958683f.tar.gz
support native exceptions and fixed bugs in IDL compiler
Diffstat (limited to 'TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp')
-rw-r--r--TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp b/TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp
index 7ef8ae84983..f2be1ad27d7 100644
--- a/TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_union_branch/public_ch.cpp
@@ -671,8 +671,8 @@ be_visitor_union_branch_public_ch::visit_union (be_union *node)
ctx.node (node); // set the node to be the node being visited. The scope
// is still the same
- // first generate the sequence declaration
- ctx.state (TAO_CodeGen::TAO_STRUCT_CH);
+ // first generate the union declaration
+ ctx.state (TAO_CodeGen::TAO_UNION_CH);
be_visitor *visitor = tao_cg->make_visitor (&ctx);
if (!visitor)
{